function formvalid() {
rut=document.getElementById("rut")
pw0=document.getElementById("contrasena0")
pw1=document.getElementById("contrasena1")
if(pers[rut.value]== undefined)
{
alert("RUT "+rut.value+" no pertenece a un prestador reconocido")
return false
}
pw=pw0.value
if(pw.length <8 )
{
alert("Clave a lo menos 8 caracteres")
return false
}
if(pw1.value!=pw0.value) {
alert("Claves no coinciden")
return false
}
 return true }
function nchange(chg)
{
//alert("PASO1 "+ chg+" "+reg+" "+registro[reg])
if(chg==1)
{
        reg=document.formularioregistro.elements[chg]
	if(registro[reg.value]!=undefined)
	{
		document.getElementById("registro").value = registro[reg.value]
		document.getElementById("contrasena0").value =""
		 //document.formularioregistro.action="./cgi-bin/formularioget.cgi1?"+registro[reg.value]
		 document.formularioregistro.submit()
	}
	else
	if(pers[reg.value]==undefined)
	{
		alert(reg.value+" No es un prestador registrado")
		reg.value=""
		location.reload()
		return
	}
}
}
document.getElementById("consultar").hidden=true
document.getElementById("contrasena0").value=""
document.getElementById("contrasena1").value=""
