function formvalid () { return true }
function nchange(chg) { return true } 
if(document.getElementById("profesional").value=="") self.close()
else document.getElementById("actualizar").disabled=false
function getPhoto(indx)
{
	idx=document.reporte07.reporte07H00.value
	if(idx=="")
	{
		alert("Debe Actualizar su reporte previamente a subir Imagenes")
		return
	}
	inx=indx.name
        vari="../cgi-bin/upload.cgi?"+idx+inx.substr(inx.indexOf("H"))
                param="width=820,height=300,top=110,left=170,menubar=no,titlebar=no,scrollbars=no,resizable=no,mimimizable=no,dialog=no"
                var obj_calwindow = window.open(vari,"",param)
}

ft01=document.getElementById("foto01").value
ft02=document.getElementById("foto02").value
ft03=document.getElementById("foto03").value
ft04=document.getElementById("foto04").value
if(ft01!="")
{
	ft=ft01.split("|")
	ft1=document.getElementById("foto1")
	ft1.src=ft[0]
	ft1.style=ft[1]
}
if(ft02!="")
{
        ft=ft02.split("|")
        ft2=document.getElementById("foto2")
        ft2.src=ft[0]
        ft2.style=ft[1]
}
if(ft03!="")
{
        ft=ft03.split("|")
        ft3=document.getElementById("foto3")
        ft3.src=ft[0]
        ft3.style=ft[1]
}
if(ft04!="")
{
        ft=ft04.split("|")
        ft4=document.getElementById("foto4")
        ft4.src=ft[0]
        ft4.style=ft[1]
}

tim=0
setInterval(function() {
if(tim++ >20) fclose()},60000)
function fclose() {if(!confirm("Este formulario cerrará por inactividad")) tim=0
else self.close()
}
