u=window.location
c=u.toString()
b=c.search("reporte")
if(document.getElementById("registro").value=="" )
document.getElementById("reporte").hidden=true
if(document.getElementById("registro").value!="" || b >=0 )
document.getElementById("ultimorep").hidden=true
function emision()
{
 rr=c.split("+")
alt=rr[6]
ix="status"+alt.substr(7)
 window.opener.document.getElementById(ix).value=2
 window.opener.document.getElementById(rr[6]).style.backgroundColor="#00ff00"
 document.reporte04.action = "https://eqt.inhedo.com/cgi-bin/emisionrep04.cgi"
 document.reporte04.submit()
}
function formvalid()
{ return true }
d0= new Date()
y1= d0.getFullYear()
m1= d0.getMonth()+1
if (m1<10) m1="0"+m1
d1=d0.getDate()
if(d1<10) d1="0"+d1
if(b>=0)
{
document.getElementById("profesional").readOnly=false
document.getElementById("pacienteid").readOnly=false
document.getElementById("fechavisita").readOnly=false
}
else document.getElementById("fecharecepcion").value=y1+"-"+m1+"-"+d1

