ff=location.href.split("?")
rf=ff[1].split("|")
fl0=rf[0]/1+1
fl1=rf[1].substr(0,rf[1].length-1)/1+1
campo=window.opener.facturadeventa.elements[(fl1/1)]
document.extradescription.elements[0].value=sku[campo.value]
if(campo=="000000") 
document.extradescription.elements[1].value=window.opener.facturadeventa.elements[(fl1/1)+3].value
else document.extradescription.elements[1].value=dsc[campo.value]
document.extradescription.elements[2].value=window.opener.facturadeventa.elements[(fl1/1)+12].value
function nchange(chg)
{
if (chg==2) 
window.opener.facturadeventa.elements[(fl1/1)+12].value=document.extradescription.elements[2].value
}
function closewin() { self.close() }
