function formvalid () { return true }
function nchange(chg) {
if(chg==2) document.tasasdecambio.elements[3].value=document.tasasdecambio.elements[2].value
if(chg==3) document.tasasdecambio.elements[2].value=document.tasasdecambio.elements[3].value
 return true } 
