function formvalid () { return true }
function nchange(chg) { return true } 
if(document.getElementById("profesional").value=="") self.close()
else document.getElementById("actualizar").disabled=false
function check()
{
for(i=0;i<65;i++)
{
	ck=document.reporte06.element[i]
	if(ck.type == "checkbox") alert("val="+ck.id+"="+ck.value)
}
}
tim=0
setInterval(function() {
if(tim++ >20) fclose()},60000)
function fclose() {if(!confirm("Este formulario cerrará por inactividad")) tim=0
else self.close()
}
