foc=0
str="str"
function focs(tt) { 
	foc=1
	str="date"
}
function closeform(str)
{
        swapin()
        myv=""
        for(i=1;i<51;i++) myv=myv+ "|" + document.referenciasDTE.elements[i].value
        window.opener.document.facturadeventa.elements[14].value=myv
	if(str=="blur" && foc==0) self.close()
	if(str=="close") self.close()
	foc=0
}
 myv=window.opener.document.facturadeventa.elements[14].value
 if(myv!="")
 {
        a=myv.split("|")
        for(i=1;i<51;i++) document.referenciasDTE.elements[i].value=a[i]
        swapout()
 }
