u=window.location
c=u.toString()
b=c.search("reporte")
if(document.getElementById("registro").value!="" || b >=0 )
document.getElementById("ultimorep").hidden=true
function emision()
{
        swapin()
 document.reporte01.action = "../cgi-bin/emisionrep01.cgi";
 document.reporte01.submit()
}

