function formvalid () { return true }
function nchange(chg)
{
if(chg==2) document.facturadeventa.elements[16].value=""
if(chg==4) document.facturadeventa.elements[5].value=document.facturadeventa.elements[4].value
if(chg==5) document.facturadeventa.elements[4].value=document.facturadeventa.elements[5].value
if(chg==8) totl()
if(chg==16) tasa()


return
}
if( document.facturadeventa.elements[1].value=="")
document.getElementById("actualizar").disabled=false
else document.getElementById("actualizar").hidden=true
